@@ -1,9 +1,11 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import
 import argparse
 import tempfile
 
 from ming.orm import session
-from pylons import tmpl_context as c
-from pylons import app_globals as g
+from tg import tmpl_context as c
+from tg import app_globals as g
 from tg import (
         config,
         expose,
@@ -99,7 +101,7 @@ class TracWikiImporter(ToolImporter):
             options.import_opts = []
             options.user_map_file = None
             options.neighborhood, options.project = project.url().strip('/').split('/',1)
-            with tempfile.NamedTemporaryFile() as f:
+            with tempfile.NamedTemporaryFile('w+') as f:
                 WikiExporter(trac_url, options).export(f)
                 f.flush()
                 load_data(f.name, WikiFromTrac.parser(), options)
@@ -113,7 +115,7 @@ class TracWikiImporter(ToolImporter):
             raise
 
     def get_token(self, user):
-        consumer_token = OAuthConsumerToken.upsert(self.classname)
+        consumer_token = OAuthConsumerToken.upsert(self.classname, user)
         request_token_params = dict(
             consumer_token_id=consumer_token._id,
             user_id=user._id,
