@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import
 from unittest import TestCase
 from mock import Mock, patch
 from ming.odm import ThreadLocalORMSession
@@ -110,11 +112,11 @@ class TestTracWikiImportController(TestController, TestCase):
         r = self.app.post('/p/test/admin/wiki/_importer/create', params,
                           status=302)
         self.assertEqual(r.location, 'http://localhost/p/test/admin/')
-        self.assertEqual(u'mymount',
+        self.assertEqual('mymount',
                          import_tool.post.call_args[1]['mount_point'])
-        self.assertEqual(u'mylabel',
+        self.assertEqual('mylabel',
                          import_tool.post.call_args[1]['mount_label'])
-        self.assertEqual(u'http://example.com/trac/url/',
+        self.assertEqual('http://example.com/trac/url/',
                          import_tool.post.call_args[1]['trac_url'])
 
     @with_wiki
